# BEL grammars

Collection of BEL grammar files written in extended Backus–Naur form (eBNF).  

The format of the files should follow this schema:

 `grammar_bel_[specification_number].bnf`

*specification_number*: Integer